Stan Math Library: stan/math/prim/scal/err/check_consistent_size.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
check_consistent_size.hpp File Reference
`#include <stan/math/prim/scal/err/invalid_argument.hpp>`
`#include <stan/math/prim/scal/meta/size_of.hpp>`
`#include <sstream>`
`#include <string>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
bool | stan::math::check_consistent_size (const char *function, const char *name, const T &x, size_t expected_size)
| Return `true` if the dimension of x is consistent, which is defined to be `expected_size` if x is a vector or 1 if x is not a vector. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.